==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tarefas",
"Due yesterday" => "Devida ontem",
"Due today" => "Devida hoje",
"Due tomorrow" => "Devida amanhã",
"Due on" => "Devida em",
"Started yesterday" => "Iniciada ontem",
"Starts today" => "Inicia hoje",
"Starts tomorrow" => "Inicia amanhã",
"Started on" => "Iniciada em",
"Starts on" => "Inicia em",
"[Remind me yesterday at ]HH:mm" => "[Lembrar-me ontem às ]HH:mm",
"[Remind me today at ]HH:mm" => "[Lembrar-me hoje às ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Lembrar-me amanhã às ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Lembrar-me em ]MMM DD, YYYY,[ às ]HH:mm",
"Yesterday" => "Ontem",
"Today" => "Hoje",
"Tomorrow" => "Amanhã",
"in %s" => "em %s",
"%s ago" => "%s atrás",
"seconds" => "segundos",
"a minute" => "um minuto",
"%d minutes" => "%d minutos",
"an hour" => "uma hora",
"%d hours" => "%d horas",
"a day" => "um dia",
"%d days" => "%d dias",
"a month" => "um mês",
"%d months" => "%d meses",
"a year" => "um ano",
"%d years" => "%d anos",
"Hours" => "Horas",
"Minutes" => "Minutos",
"week" => "semana",
"weeks" => "semanas",
"day" => "dia",
"days" => "dias",
"hour" => "hora",
"hours" => "horas",
"minute" => "minuto",
"minutes" => "minutos",
"second" => "segundo",
"before beginning" => "antes de iniciar",
"after beginning" => "depois de iniciar",
"before end" => "antes de terminar",
"after end" => "depois de terminar",
"Comment" => "Comentário",
"Add a comment" => "Adicione um comentário",
"This will delete the Calendar \"%s\" and all of its entries." => "Isto irá apagar o Calendário \"%s\" e todas as suas entradas.",
"The name \"%s\" is already used." => "O nome \"%s\" já está em uso.",
"An empty name is not allowed." => "Não é permitido um nome em branco.",
"Hidden" => "Ocultado",
"Visible" => "Visível",
"Automatic" => "Automático",
"Sunday" => "Domingo",
"Monday" => "Segunda",
"Tuesday" => "Terça",
"Wednesday" => "Quarta",
"Thursday" => "Quinta",
"Friday" => "Sexta",
"Saturday" => "Sábado",
"Add an important item in \"%s\"..." => "Adicione um item importante em \"%s\"...",
"Add an item due today in \"%s\"..." => "Adicionar um item devido hoje em \"%s\" ...",
"Add an item in \"%s\"..." => "Adicionar um item em \"%s\" ...",
"Add a current item in \"%s\"..." => "Adicionar um item atual em \"%s\" ...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n Tarefa Concluída","%n Tarefas Concluídas"),
"Set due date" => "Definir data de expiração",
"%s %% completed" => "%s %% completo",
"priority %s: " => "prioridade %s: ",
"high" => "alto",
"medium" => "médio",
"low" => "baixo",
"Remind me" => "Lembrar-me",
"at the end" => "no fim",
"at the beginning" => "no início",
"Set start date" => "Defina data de inicio ",
"Important" => "Importante",
"Week" => "Semana",
"All" => "Todos",
"Current" => "Atual",
"Completed" => "Concluída",
"rename" => "renomear",
"delete" => "eliminar",
"Add List..." => "Adicionar Lista...",
"New List" => "Nova Lista",
"Settings" => "Definições",
"Start of week" => "Inicio da semana",
"Visibility of Smart Collections" => "Visibilidade das Coleções Inteligentes",
"Load remaining completed tasks." => "Carregar as tarefas concluídas restantes.",
"(New category)" => "(Nova categoria)",
"Select categories..." => "Seleccione categorias...",
"Loading the task..." => "A carregar a tarefa...",
"Task not found!" => "Tarefa não encontrada!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tarefas",
"Tasks app is unavailable because the calendar is not installed" => "A app de tarefas está indisponível porque o calendário não está instalado.",
"Due yesterday" => "Devida ontem",
"Due today" => "Devida hoje",
"Due tomorrow" => "Devida amanhã",
"Due on" => "Devida em",
"Started yesterday" => "Iniciada ontem",
"Starts today" => "Inicia hoje",
"Starts tomorrow" => "Inicia amanhã",
"Started on" => "Iniciada em",
"Starts on" => "Inicia em",
"[Remind me yesterday at ]HH:mm" => "[Lembrar-me ontem às ]HH:mm",
"[Remind me today at ]HH:mm" => "[Lembrar-me hoje às ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Lembrar-me amanhã às ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Lembrar-me em ]MMM DD, YYYY,[ às ]HH:mm",
"Yesterday" => "Ontem",
"Today" => "Hoje",
"Tomorrow" => "Amanhã",
"in %s" => "em %s",
"%s ago" => "há %s",
"seconds" => "segundos",
"a minute" => "um minuto",
"%d minutes" => "%d minutos",
"an hour" => "uma hora",
"%d hours" => "%d horas",
"a day" => "um dia",
"%d days" => "%d dias",
"a month" => "um mês",
"%d months" => "%d meses",
"a year" => "um ano",
"%d years" => "%d anos",
"Hours" => "Horas",
"Minutes" => "Minutos",
"week" => "semana",
"weeks" => "semanas",
"day" => "dia",
"days" => "dias",
"hour" => "hora",
"hours" => "horas",
"minute" => "minuto",
"minutes" => "minutos",
"second" => "segundo",
"before beginning" => "antes de iniciar",
"after beginning" => "depois de iniciar",
"before end" => "antes de terminar",
"after end" => "depois de terminar",
"Comment" => "Comentário",
"Add a comment" => "Adicione um comentário",
"This will delete the Calendar \"%s\" and all of its entries." => "Isto irá apagar o Calendário \"%s\" e todas as suas entradas.",
"The name \"%s\" is already used." => "O nome \"%s\" já está em uso.",
"An empty name is not allowed." => "Não é permitido um nome em branco.",
"Hidden" => "Ocultado",
"Visible" => "Visível",
"Automatic" => "Automático",
"Sunday" => "Domingo",
"Monday" => "Segunda",
"Tuesday" => "Terça",
"Wednesday" => "Quarta",
"Thursday" => "Quinta",
"Friday" => "Sexta",
"Saturday" => "Sábado",
"Add an important item in \"%s\"..." => "Adicione um item importante em \"%s\"...",
"Add an item due today in \"%s\"..." => "Adicionar um item devido hoje em \"%s\" ...",
"Add an item in \"%s\"..." => "Adicionar um item em \"%s\" ...",
"Add a current item in \"%s\"..." => "Adicionar um item atual em \"%s\" ...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n Tarefa Concluída","%n Tarefas Concluídas"),
"Set due date" => "Definir data de expiração",
"%s %% completed" => "%s %% completo",
"priority %s: " => "prioridade %s: ",
"high" => "alto",
"medium" => "médio",
"low" => "baixo",
"Remind me" => "Lembrar-me",
"at the end" => "no fim",
"at the beginning" => "no início",
"Set start date" => "Defina data de inicio ",
"Important" => "Importante",
"Week" => "Semana",
"All" => "Todos",
"Current" => "Atual",
"Completed" => "Concluída",
"rename" => "renomear",
"delete" => "eliminar",
"Add List..." => "Adicionar Lista...",
"New List" => "Nova Lista",
"Settings" => "Definições",
"Start of week" => "Inicio da semana",
"Visibility of Smart Collections" => "Visibilidade das Coleções Inteligentes",
"Load remaining completed tasks." => "Carregar as tarefas concluídas restantes.",
"(New category)" => "(Nova categoria)",
"Select categories..." => "Seleccione categorias...",
"Loading the task..." => "A carregar a tarefa...",
"Task not found!" => "Tarefa não encontrada!",
"add a subtask to" => "adicionar uma subtarefa a"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
